Statistics » Referral to Treatment (RTT) Waiting Times
Author: Statistics

Skip to main content

# Cookies on the NHS England website

We've put some small files called cookies on your device to make our site work. We'd also like to use analytics cookies. These send information about how our site is used to a service called Google Analytics. We use this information to improve our site. Let us know if this is OK. We'll use a cookie to save your choice. You can read more about our cookies before you choose.

# Referral to Treatment (RTT) Waiting Times

This section contains information on Consultant-led Referral To Treatment (RTT) waiting times, which monitor the length of time from referral through to elective treatment.

Monthly RTT waiting times data has been published since March 2007. Initially data was only published for cases where patients started treatment during the month and the treatment involved admission to hospital (completed admitted pathways). Completed non-admitted pathway data (cases where patients completed their RTT pathway during the month for reasons other than an inpatient or day case admission to hospital for treatment) has been published since August 2007. Incomplete RTT pathway data (cases where patients are still waiting to start treatment at the end of the reporting period) has also been published since August 2007. Adjusted completed admitted RTT pathway data was published from March 2008 to September 2015. Incomplete RTT pathway with a decision to admit for treatment data and New RTT period data has been published since October 2015.

### Latest data

2025-26 RTT waiting times data
2024-25 RTT waiting times data
2023-24 RTT waiting times data
2022-23 RTT waiting times data
2021-22 RTT waiting times data
2020-21 RTT waiting times data
2019-20 RTT waiting times data
2018-19 RTT waiting times data
2017-18 RTT waiting times data
2016-17 RTT waiting times data
2015-16 RTT waiting times data
2014-15 RTT waiting times data
2013-14 RTT waiting times data
2012-13 RTT waiting times data
2011-12 RTT waiting times data
Data prior to 2011-12 is currently still found here on the old RTT web page

### Pre-release Access List

Pre-release access list (PDF, 92K)

### Annual Statistical Report

Download 2019_20 Annual Report (PDF, 734K)
2019-20 Annual Report – spreadsheet (XLS 99K)

Download 2018_19 RTT Annual Report (PDF, 1336K)
2018_19 Annual Report – spreadsheet (XLS, 51K)

Download 2017_18 RTT Annual Report (PDF, 1295K)
2017_18 Annual Report – spreadsheet (XLS, 51K)

Download 2016_17 RTT Annual Report (PDF, 1484K)
2016_17 Annual Report – spreadsheet (XLS, 48K)

Download 2015_16 RTT Annual Report v2 (PDF, 564K)
2015_16 Annual Report – spreadsheet (XLS, 46K)

Download 2014 Annual Report (PDF, 2985K)
2014 Annual Report – spreadsheet (XLS, 46K)

Download 2013 Annual Report (PDF, 1749K)
Download 2012 Annual Report (PDF, 152K)
Download 2011 Annual Report (PDF, 155K)
Download 2010 Annual Report (PDF, 362K)
Download 2009 Annual Report (PDF, 283K)

### Recovery of Elective Activity Information

Recovery of Elective Activity

### Waiting List Minimum Dataset (WLMDS) Information

RTT WLMDS summary information

### Guidance

RTT waiting times clock rules and FAQ
Guide to waiting times for patients

### Contact Us

For further information about the published statistics, please contact us at:

Operational Insights
NHS England
7 & 8 Wellington Place
Leeds
LS1 4AP

Email: england.rtt@nhs.net

If you are a patient wishing to discuss your own waiting time experience, you should contact your local commissioner, which you can find via the NHS website.